/* This file was generated by syncqt. */
#ifndef QT_QTGRPCQUICK_VERSION_H
#define QT_QTGRPCQUICK_VERSION_H

#define QTGRPCQUICK_VERSION_STR "6.11.1"

#define QTGRPCQUICK_VERSION 0x0601101

#endif // QT_QTGRPCQUICK_VERSION_H
